.. _spkg_libogg:

libogg: Library for the Ogg multimedia container format
=================================================================

Description
-----------

libogg is the official reference library for the Ogg multimedia
container format, and the native file and stream format for the Xiph.org
multimedia codecs. As with all Xiph.org technology is it an open format
free for anyone to use.

Website: http://www.xiph.org/ogg

License
-------

Copyright (c) 2002, Xiph.org Foundation

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

-  Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

-  Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

-  Neither the name of the Xiph.org Foundation nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
   PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FOUNDATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


Upstream Contact
----------------

The Xiph.org mailing lists - see http://lists.xiph.org/mailman/listinfo

Special Update/Build Instructions
---------------------------------

-  No changes went into src.

Type
----

optional


Dependencies
------------


Version Information
-------------------

package-version.txt::

    1.3.1.p0


Equivalent System Packages
--------------------------

.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install libogg 


.. tab:: Fedora/Redhat/CentOS

   .. CODE-BLOCK:: bash

       $ sudo dnf install libogg libogg-devel 


.. tab:: Homebrew

   .. CODE-BLOCK:: bash

       $ brew install libogg 


.. tab:: MacPorts

   .. CODE-BLOCK:: bash

       $ sudo port install libogg 


.. tab:: openSUSE

   .. CODE-BLOCK:: bash

       $ sudo zypper install pkgconfig\(ogg\) 


.. tab:: Void Linux

   .. CODE-BLOCK:: bash

       $ sudo xbps-install libogg-devel 



See https://repology.org/project/libogg/versions

However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.

